OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Jūs sukūrėte naują lentą {board}",
    "{user} has created a new board {board}" : "{user} sukūrė naują lentą {board}",
    "You have deleted the board {board}" : "Jūs ištrynėte lentą {board}",
    "{user} has deleted the board {board}" : "{user} ištrynė lentą {board}",
    "You have restored the board {board}" : "Jūs atkūrėte lentą {board}",
    "{user} has restored the board {board}" : "{user} atkūrė lentą {board}",
    "You have shared the board {board} with {acl}" : "Jūs pradėjote bendrinti lentą {board} su {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} pradėjo bendrinti lentą {board} su {acl}",
    "You have removed {acl} from the board {board}" : "Jūs pašalinote {acl} iš lentos {board}",
    "{user} has removed {acl} from the board {board}" : "{user} pašalino {acl} iš lentos {board}",
    "You have renamed the board {before} to {board}" : "Jūs pervadinote lentą {before} į {board}",
    "{user} has renamed the board {before} to {board}" : "{user} pervadino lentą {before} į {board}",
    "You have archived the board {board}" : "Jūs užarchyvavote lentą {board}",
    "{user} has archived the board {before}" : "{user} užarchyvavo lentą {before}",
    "You have unarchived the board {board}" : "Jūs išarchyvavote lentą {board}",
    "{user} has unarchived the board {before}" : "{user} išarchyvavo lentą {before}",
    "You have renamed the card {before} to {card}" : "Jūs pervadinote kortelę {before} į {card}",
    "{user} has renamed the card {before} to {card}" : "{user} pervadino kortelę {before} į {card}",
    "You have removed the due date of card {card}" : "Jūs pašalinote galutinį kortelės {card} terminą",
    "{user} has removed the due date of card {card}" : "{user} pašalino galutinį kortelės {card} terminą",
    "You have set the due date of card {card} to {after}" : "Jūs nustatėte galutinį kortelės {card} terminą į {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} nustatė galutinį kortelės {card} terminą į {after}",
    "You have updated the due date of card {card} to {after}" : "Jūs atnaujinote galutinį kortelės {card} terminą į {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} atnaujino galutinį kortelės {card} terminą į {after}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Jūs lentoje {board} prie kortelės {card} priskyrėte {assigneduser}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} lentoje {board} prie kortelės {card} priskyrė {assigneduser}",
    "You have added the attachment {attachment} to card {card}" : "Jūs pridėjote priedą {attachment} į kortelę {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} pridėjo priedą {attachment} į kortelę {card}",
    "You have updated the attachment {attachment} on card {card}" : "Jūs atnaujinote priedą {attachment} kortelėje {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} atnaujino priedą {attachment} kortelėje {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Jūs ištrynėte priedą {attachment} iš kortelės {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} ištrynė priedą {attachment} iš kortelės {card}",
    "You have restored the attachment {attachment} to card {card}" : "Jūs atkūrėte priedą {attachment} į kortelę {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} atkūrė priedą {attachment} į kortelę {card}",
    "You have commented on card {card}" : "Jūs pakomentavote kortelėje {card}",
    "{user} has commented on card {card}" : "{user} pakomentavo kortelėje {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Darbų programėlėje pakeistas <strong>kortelės aprašas</strong> ",
    "Deck" : "Darbai",
    "Changes in the <strong>Deck app</strong>" : "Pakeitimai <strong>Darbų programėlėje</strong>",
    "A <strong>comment</strong> was created on a card" : "Kortelėje buvo sukurtas <strong>komentaras</strong>",
    "Personal" : "Asmeniniai",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} priskyrė jums kortelę \"%s\" ties \"%s\".",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė \"%s\" ties \"%s\" pasiekė savo galutinį terminą.",
    "%s has mentioned you in a comment on \"%s\"." : "%s paminėjo jus komentare ties \"%s\".",
    "{user} has mentioned you in a comment on \"%s\"." : "{user} paminėjo jus komentare ties \"%s\".",
    "The board \"%s\" has been shared with you by %s." : "Lentą \"%s\" su jumis bendrina %s.",
    "{user} has shared the board %s with you." : "{user} pradėjo su jumis bendrinti lentą %s.",
    "No data was provided to create an attachment." : "Priedo sukūrimui nebuvo pateikta jokių duomenų.",
    "Finished" : "Baigta",
    "To review" : "Reikia peržiūrėti",
    "Action needed" : "Reikalingas veiksmas",
    "Later" : "Vėliau",
    "copy" : "kopija",
    "To do" : "Reikia atlikti",
    "Doing" : "Atliekama",
    "Done" : "Atlikta",
    "Example Task 3" : "Pavyzdinė užduotis 3",
    "Example Task 2" : "Pavyzdinė užduotis 2",
    "Example Task 1" : "Pavyzdinė užduotis 1",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
    "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
    "Create new board" : "Sukurti naują lentą",
    "new board" : "nauja lenta",
    "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
    "Search by board title" : "Ieškoti pagal lentos pavadinimą",
    "Select board" : "Pasirinkti lentą",
    "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
    "Select a board" : "Pasirinkite lentą",
    "Select a card" : "Pasirinkti kortelę",
    "Link to card" : "Susieti su kortele",
    "Cancel" : "Atsisakyti",
    "File already exists" : "Failas jau yra",
    "A file with the name {filename} already exists." : "Failas, pavadinimu {filename}, jau yra.",
    "Do you want to overwrite it?" : "Ar norite jį perrašyti?",
    "Overwrite file" : "Perrašyti failą",
    "Keep existing file" : "Palikti esamą failą",
    "This board is read only" : "Ši lenta yra tik skaitymui",
    "Archived cards" : "Archyvuotos kortelės",
    "Add new list" : "Pridėti naują sąrašą",
    "List name" : "Sąrašo pavadinimas",
    "Apply filter" : "Taikyti filtrą",
    "Filter by tag" : "Filtruoti pagal žymę",
    "Filter by assigned user" : "Filtruoti pagal priskirtą naudotoją",
    "Filter by due date" : "Filtruoti pagal galutinio termino datą",
    "Overdue" : "Praėjęs galutinis terminas",
    "Next 24 hours" : "Artimiausios 24 val.",
    "Next 7 days" : "Artimiausios 7 dienos",
    "Next 30 days" : "Artimiausios 30 dienų",
    "No due date" : "Be galutinio termino",
    "Clear filter" : "Išvalyti filtrą",
    "Show archived cards" : "Rodyti archyvuotas korteles",
    "Toggle compact mode" : "Perjungti kompaktišką veikseną",
    "Details" : "Išsamiau",
    "Loading board" : "Įkeliama lenta",
    "Board not found" : "Lenta nerasta",
    "Sharing" : "Bendrinimas",
    "Tags" : "Žymės",
    "Deleted items" : "Ištrinti elementai",
    "Timeline" : "Laiko juosta",
    "Deleted lists" : "Ištrinti sąrašai",
    "Undo" : "Atšaukti",
    "Deleted cards" : "Ištrintos kortelės",
    "Share board with a user, group or circle …" : "Bendrinti lentą su naudotoju, grupe ar ratu…",
    "Board owner" : "Lentos savininkas",
    "(Group)" : "(Grupė)",
    "(Circle)" : "(Ratas)",
    "Can edit" : "Gali redaguoti",
    "Can share" : "Can share",
    "Can manage" : "Gali tvarkyti",
    "Delete" : "Ištrinti",
    "Delete list" : "Ištrinti sąrašą",
    "Add card" : "Pridėti kortelę",
    "Add a new card" : "Pridėti naują kortelę",
    "Edit" : "Taisyti",
    "Add a new tag" : "Pridėti naują žymę",
    "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
    "Title" : "Pavadinimas",
    "Members" : "Nariai",
    "Add this attachment" : "Pridėti šį priedą",
    "Delete Attachment" : "Ištrinti priedą",
    "Restore Attachment" : "Atkurti priedą",
    "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
    "Assign to users" : "Priskirti naudotojams",
    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
    "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
    "Due date" : "Terminas",
    "Set a due date" : "Nustatyti galutinį terminą",
    "Remove due date" : "Pašalinti terminą",
    "Description" : "Aprašas",
    "(Unsaved)" : "(Neįrašyta)",
    "(Saving…)" : "(Įrašoma…)",
    "Formatting help" : "Formatavimo pagalba",
    "Edit description" : "Taisyti aprašą",
    "View description" : "Rodyti aprašą",
    "Add Attachment" : "Pridėti priedą",
    "Attachments" : "Priedai",
    "Comments" : "Komentarai",
    "Choose attachment" : "Pasirinkite priedą",
    "Modified" : "Pakeistas",
    "Created" : "Sukurta",
    "Upload attachment" : "Įkelti priedą",
    "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
    "Save" : "Įrašyti",
    "The comment cannot be empty." : "Komentaras negali būti tuščias.",
    "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
    "Reply" : "Atsakyti",
    "Update" : "Atnaujinti",
    "(group)" : "(grupė)",
    "(circle)" : "(ratas)",
    "seconds ago" : "prieš keletą sekundžių",
    "Assign to me" : "Priskirti sau",
    "Unarchive card" : "Išarchyvuoti kortelę",
    "Archive card" : "Archyvuoti kortelę",
    "Delete card" : "Ištrinti kortelę",
    "Move card" : "Perkelti kortelę",
    "Card details" : "Išsamiau apie kortelę",
    "Move card to another board" : "Perkelti kortelę į kitą lentą",
    "All boards" : "Visos lentos",
    "Archived boards" : "Archyvuotos lentos",
    "Shared with you" : "Bendrinama su jumis",
    "New board title" : "Naujos lentos pavadinimas",
    "Edit board" : "Taisyti lentą",
    "Clone board " : "Dubliuoti lentą ",
    "Unarchive board " : "Išarchyvuoti lentą ",
    "Archive board " : "Archyvuoti lentą ",
    "Delete board " : "Ištrinti lentą ",
    "Board details" : "Išsamiau apie lentą",
    "Board {0} deleted" : "Lenta {0} ištrinta",
    "An error occurred" : "Įvyko klaida",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
    "Delete the board?" : "Ištrinti lentą?",
    "Link to a board" : "Susieti su lenta",
    "Link to a card" : "Susieti su kortele",
    "Something went wrong" : "Kažkas nutiko",
    "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
